@@ -188,7 +188,7 @@ class Link:
 
 
 class Agent:
-    """ individual agent derived from aggragted demand between an OD pair
+    """ individual agent derived from aggregated demand between an OD pair
 
     agent_id: integer starts from 1
     agent_seq_no: internal agent index starting from 0 used for calculation
@@ -272,7 +272,7 @@ class Network:
         self.link_predecessor = None
         # added for CG
         self.zones = None
-        self.has_capi_allocated = False
+        self.capi_allocated = False
         # the following two are IDs rather than objects
         self._agent_type_size = 1
         self._demand_period_size = 1
@@ -289,7 +289,7 @@ class Network:
 
     def allocate_for_CAPI(self):
         # execute only on the first call
-        if self.has_capi_allocated:
+        if self.capi_allocated:
             return
 
         node_size = self.node_size
@@ -305,7 +305,7 @@ class Network:
         to_node_no_array = [link.to_node_seq_no for link in self.link_list]
         link_cost_array = [link.cost for link in self.link_list]
 
-        # initialize others as numpy arrays directly
+        # initialize others
         queue_next = [0] * node_size
         first_link_from = [-1] * node_size
         last_link_from = [-1] * node_size
@@ -324,8 +324,6 @@ class Network:
             last_link_from[i] = j
 
         # setup allowed uses
-        # allowed_uses = [''] * link_size
-        # self._setup_allowed_use(allowed_uses)
         allowed_uses = [link.allowed_uses for link in self.link_list]
 
         # set up arrays using ctypes
@@ -348,7 +346,7 @@ class Network:
         self.queue_next = int_arr_node(*queue_next)
         self.allowed_uses = char_arr_link(*allowed_uses)
 
-        self.has_capi_allocated = True
+        self.capi_allocated = True
 
     def setup_agents(self, column_pool):
         agent_id = 1
@@ -436,7 +434,7 @@ class Network:
 
         path_cost = agent.get_path_cost()
         if path_cost >= MAX_LABEL_COST:
-            return f'distance: infinitity | path: '
+            return f'distance: infinity | path: '
 
         path = ''
         if agent.node_path:
@@ -460,7 +458,7 @@ class Network:
 
         path_cost = agent.get_path_cost()
         if path_cost >= MAX_LABEL_COST:
-            return f'distance: infinitity | path: '
+            return f'distance: infinity | path: '
 
         path = ''
         if agent.link_path:
@@ -569,7 +567,7 @@ class Network:
 
 
 class Column:
-
+    """ column is path """
     def __init__(self, seq_no=-1):
         self.seq_no = seq_no
         self.vol = 0
@@ -618,9 +616,13 @@ class Column:
         return self.gradient_cost_rel_diff
 
     def get_links(self):
-        """ return link seq no """
+        """ return link path """
         return self.links
 
+    def get_nodes(self):
+        """ return node path """
+        return self.nodes
+
     def set_distance(self, d):
         self.dist = d
 
@@ -656,7 +658,13 @@ class Column:
 
 
 class ColumnVec:
+    """ column pool for (at, dp, oz, dz)
 
+    where, at is agent type id,
+           dp is demand period id,
+           oz is origin zone id,
+           dz is destination zone id.
+    """
     def __init__(self):
         self.od_vol = 0
         self.route_fixed = False
@@ -677,8 +685,8 @@ class ColumnVec:
     def get_column(self, k):
         return self.path_node_seq_map[k]
 
-    def add_new_column(self, node_sum, col):
-        self.path_node_seq_map[node_sum] = col
+    def add_new_column(self, k, col):
+        self.path_node_seq_map[k] = col
 
 
 class AgentType:
@@ -723,9 +731,6 @@ class DemandPeriod:
     def get_id(self):
         return self.id
 
-    def get_file_name(self):
-        return self.file
-
     def get_period(self):
         return self.period
 
@@ -810,8 +815,8 @@ class SPNetwork(Network):
         self.demand_period = dp
 
         # this is necessary for each instance of SPNetwork
-        # to retrieve network topoloy
-        if not base.has_capi_allocated:
+        # to retrieve network topology
+        if not base.capi_allocated:
             base.allocate_for_CAPI()
 
         # set up attributes unique to each instance
@@ -836,7 +841,7 @@ class SPNetwork(Network):
         # zone sequence no
         self.orig_zones = []
         self.node_id_to_no = {}
-        self.has_capi_allocated = True
+        self.capi_allocated = True
 
     def add_orig_nodes(self, nodes):
         self.orig_nodes.extend(nodes)
@@ -938,7 +943,7 @@ class AccessNetwork(Network):
         self.pre_source_node_id = -1
         if add_cc:
             self._add_centroids_connectors()
-        self.has_capi_allocated = False
+        self.capi_allocated = False
         super().allocate_for_CAPI()
 
     def _add_centroids_connectors(self):
@@ -1257,7 +1262,7 @@ class Assignment:
         return self.network.get_agent_orig_node_id(agent_id)
 
     def get_agent_dest_node_id(self, agent_id):
-        """ return the destnation node id of an agent
+        """ return the destination node id of an agent
 
         exception will be handled by _get_agent() in class Network
         """
@@ -1451,7 +1456,7 @@ class UI:
         return self._base_assignment.get_agent_orig_node_id(agent_id)
 
     def get_agent_dest_node_id(self, agent_id):
-        """ return the destnation node id of an agent """
+        """ return the destination node id of an agent """
         return self._base_assignment.get_agent_dest_node_id(agent_id)
 
     def get_agent_node_path(self, agent_id):
