@@ -112,9 +112,8 @@ def _update_column_gradient_cost_and_flow(column_pool,
         column_num = cv.get_column_num()
         least_gradient_cost = MAX_LABEL_COST
         least_gradient_cost_path_seq_no = -1
-        least_gradient_cost_path_node_sum = -1
 
-        for node_sum, col in cv.get_columns().items():
+        for col in cv.get_columns().values():
             path_toll = 0
             path_gradient_cost = 0
             path_travel_time = 0
@@ -141,7 +140,6 @@ def _update_column_gradient_cost_and_flow(column_pool,
             if path_gradient_cost < least_gradient_cost:
                 least_gradient_cost = path_gradient_cost
                 least_gradient_cost_path_seq_no = col.get_seq_no()
-                least_gradient_cost_path_node_sum = node_sum
 
         if column_num >= 2:
             total_switched_out_path_vol = 0
@@ -180,7 +178,7 @@ def _update_column_gradient_cost_and_flow(column_pool,
                 total_switched_out_path_vol += col.get_switch_volume()
 
         if least_gradient_cost_path_seq_no != -1:
-            col = cv.get_column(least_gradient_cost_path_node_sum)
+            col = cv.get_column(least_gradient_cost_path_seq_no)
             col.increase_volume(total_switched_out_path_vol)
             # total_gap_count += (
             #     col.get_gradient_cost() * col.get_volume()
@@ -197,7 +195,7 @@ def _optimize_column_pool(column_pool,
                           column_update_num):
 
     for i in range(column_update_num):
-        print(f'current iteration number in column generation: {i}')
+        print(f'current iteration number in column update: {i}')
         _update_column_gradient_cost_and_flow(column_pool,
                                               links,
                                               agent_types,
@@ -248,12 +246,10 @@ def _backtrace_shortest_path_tree(orig_node_no,
         link_path = []
 
         dist = 0
-        node_sum = 0
         current_node_seq_no = i
         # retrieve the sequence backwards
         while current_node_seq_no >= 0:
             node_path.append(current_node_seq_no)
-            node_sum += current_node_seq_no
 
             current_link_seq_no = link_preds[current_node_seq_no]
             if current_link_seq_no >= 0:
@@ -266,20 +262,25 @@ def _backtrace_shortest_path_tree(orig_node_no,
         if not link_path:
             continue
 
-        if node_sum not in cv.path_node_seq_map.keys():
+        existing = False
+        for col in cv.get_columns().values():
+            if col.get_links() == link_path:
+                col.increase_volume(vol)
+                existing = True
+                break
+
+        if not existing:
             path_seq_no = cv.get_column_num()
             col = Column(path_seq_no)
+            col.set_volume(vol)
+            col.set_distance(dist)
             col.set_toll(node_label_costs[i])
             col.nodes = [x for x in node_path]
             col.links = [x for x in link_path]
-            col.set_distance(dist)
-            cv.add_new_column(node_sum, col)
-
-        cv.get_column(node_sum).increase_volume(vol)
+            cv.add_new_column(path_seq_no, col)
 
 
 def _update_column_travel_time(column_pool, links):
-
     for k, cv in column_pool.items():
         if cv.get_od_volume() <= 0:
             continue
@@ -294,8 +295,7 @@ def _update_column_travel_time(column_pool, links):
             col.set_travel_time(travel_time)
 
 
-def _assignment_core(spn, column_pool, iter_num):
-
+def _generate(spn, column_pool, iter_num):
     for node_id in spn.get_orig_nodes():
         single_source_shortest_path(spn, node_id)
 
@@ -311,15 +311,15 @@ def _assignment_core(spn, column_pool, iter_num):
                                       iter_num)
 
 
-def _assignment(spnetworks, column_pool, iter_num):
+def _generate_column_pool(spnetworks, column_pool, iter_num):
     # single processing
     # it could be multiprocessing
     for spn in spnetworks:
-        _assignment_core(spn, column_pool, iter_num)
+        _generate(spn, column_pool, iter_num)
 
 
-def perform_column_generation(iter_num, column_update_num, ui):
-    """ perform network assignemnt using the selected assignment mode
+def perform_column_generation(column_gen_num, column_update_num, ui):
+    """ perform network assignment using the selected assignment mode
 
     WARNING
     -------
@@ -329,11 +329,11 @@ def perform_column_generation(iter_num, column_update_num, ui):
 
     Parameters
     ----------
-    iter_num
-        number of assignment iterations to be performed before optimizing
+    column_gen_num
+        number of iterations to be performed on generating column pool
         column pool
 
-    column_update_iter
+    column_update_num
         number of iterations to be performed on optimizing column pool
 
     ui
@@ -349,7 +349,7 @@ def perform_column_generation(iter_num, column_update_num, ui):
         ink_performance.csv)
     """
     # make sure iteration numbers are both non-negative
-    assert(iter_num>=0)
+    assert(column_gen_num>=0)
     assert(column_update_num>=0)
 
     # base assignment
@@ -362,8 +362,8 @@ def perform_column_generation(iter_num, column_update_num, ui):
 
     st = time()
 
-    for i in range(iter_num):
-        print(f'current iteration number in assignment: {i}')
+    for i in range(column_gen_num):
+        print(f'current iteration number in column generation: {i}')
         _update_link_travel_time_and_cost(links)
 
         _reset_and_update_link_vol_based_on_columns(column_pool,
@@ -376,16 +376,16 @@ def perform_column_generation(iter_num, column_update_num, ui):
         _update_generalized_link_cost(A.get_spnetworks())
 
         # loop through all nodes on the base network
-        _assignment(A.get_spnetworks(), column_pool, i)
+        _generate_column_pool(A.get_spnetworks(), column_pool, i)
 
-    print(f'\nprocessing time of assignment: {time()-st:.2f} s')
+    print(f'\nprocessing time of generating columns: {time()-st:.2f} s')
 
     _optimize_column_pool(column_pool, links, ats, dps, column_update_num)
 
     _reset_and_update_link_vol_based_on_columns(column_pool,
                                                 links,
                                                 dps,
-                                                iter_num,
+                                                column_gen_num,
                                                 False)
 
     _update_link_travel_time_and_cost(links)
@@ -411,7 +411,7 @@ def update_links_using_columns(network):
     _update_link_travel_time_and_cost(links)
 
 
-def perform_network_assignment(assignment_mode, iter_num, column_update_num, ui):
+def perform_network_assignment(assignment_mode, column_gen_num, column_update_num, ui):
     """DEPRECATED Column Generation API
 
     Keep it here as legacy support for existing users who already get used to it
@@ -425,4 +425,4 @@ def perform_network_assignment(assignment_mode, iter_num, column_update_num, ui)
             'Please please use perform_network_assignment_DTALite().'
         )
 
-    perform_column_generation(iter_num, column_update_num, ui)
\ No newline at end of file
+    perform_column_generation(column_gen_num, column_update_num, ui)
\ No newline at end of file
