@@ -1,6 +1,8 @@
 """ global constants """
 # for shortest path calculation
-MAX_LABEL_COST = 99999
+MAX_LABEL_COST = 999999
+# in case where the divisor/demoninator is ZERO
+SMALL_DIVISOR = 0.001
 # for column generation
 MIN_OD_VOL = 0.000001
 # for accessibility evaluation
