@@ -38,7 +38,7 @@ else:
 _cdll = ctypes.cdll.LoadLibrary(_dll_file)
 
 # set up the argument types for the shortest path function in dll.
-_cdll.shortest_path.argtypes = [
+_cdll.shortest_path_n.argtypes = [
     ctypes.c_int,
     ctypes.c_int,
     ctypes.POINTER(ctypes.c_int),
@@ -287,7 +287,7 @@ def find_shortest_path(G, from_node_id, to_node_id, seq_type='node'):
     path_cost = _get_path_cost(G, to_node_id)
 
     if path_cost == MAX_LABEL_COST:
-        return f'distance: infinitity | path: '
+        return f'distance: infinity | path: '
 
     path = ';'.join(
         str(x) for x in output_path_sequence(G, to_node_id, seq_type)
