@@ -94,7 +94,7 @@ def _download_url(url, filename, loc_dir):
     try:
         import requests
     except ImportError:
-        print('please print requests to preceed downloading!!')
+        print('please print requests to proceed downloading!!')
 
     try:
         r = requests.get(url)
@@ -195,7 +195,7 @@ def read_nodes(input_dir,
             id_to_no_dict[node_id] = node_seq_no
             no_to_id_dict[node_seq_no] = node_id
 
-            # associate node_id to corresponding zone
+            # associate node_id with corresponding zone
             if zone_id not in zone_to_node_dict.keys():
                 zone_to_node_dict[zone_id] = []
             zone_to_node_dict[zone_id].append(node_id)
@@ -231,7 +231,7 @@ def read_links(input_dir,
             # it can be an empty string
             link_id = line['link_id']
 
-            # check the validility
+            # check the validity
             from_node_id = _convert_str_to_int(line['from_node_id'])
             if from_node_id is None:
                 continue
@@ -244,7 +244,7 @@ def read_links(input_dir,
             if length is None:
                 continue
 
-            # pass validility check
+            # pass validity check
 
             try:
                 from_node_no = id_to_no_dict[from_node_id]
@@ -275,9 +275,9 @@ def read_links(input_dir,
                 capacity = 49500
 
             # if link.csv does not have no column 'allowed_uses',
-            # set allowed_uses to 'auto'
+            # set allowed_uses to 'all'
             # developer's note:
-            # we may need to change this implemenation as we cannot deal with
+            # we may need to change this implementation as we cannot deal with
             # cases a link which is not open to any modes
             try:
                 allowed_uses = line['allowed_uses']
@@ -295,7 +295,7 @@ def read_links(input_dir,
 
             link_id_dict[link_id] = link_seq_no
 
-            # construct link ojbect
+            # construct link object
             link = Link(link_id,
                         link_seq_no,
                         from_node_no,
@@ -314,18 +314,19 @@ def read_links(input_dir,
 
             # VDF Attributes
             for i in range(demand_period_size):
-                header_vdf_alpha = 'VDF_alpha' + str(i+1)
-                header_vdf_beta = 'VDF_beta' + str(i+1)
-                header_vdf_mu = 'VDF_mu' + str(i+1)
-                header_vdf_fftt = 'VDF_fftt' + str(i+1)
-                header_vdf_cap = 'VDF_cap' + str(i+1)
-                header_vdf_phf = 'VDF_phf' + str(i+1)
+                dp_id_str = str(i+1)
+                header_vdf_alpha = 'VDF_alpha' + dp_id_str
+                header_vdf_beta = 'VDF_beta' + dp_id_str
+                header_vdf_mu = 'VDF_mu' + dp_id_str
+                header_vdf_fftt = 'VDF_fftt' + dp_id_str
+                header_vdf_cap = 'VDF_cap' + dp_id_str
+                header_vdf_phf = 'VDF_phf' + dp_id_str
 
                 # case i: link.csv does not VDF attributes at all
                 # case ii: link.csv only has partial VDF attributes
-                # under case i, we will set up only one VDFPeriod ojbect using
+                # under case i, we will set up only one VDFPeriod object using
                 # default values
-                # under case ii, we will set up some VDFPeriod ojbects up to
+                # under case ii, we will set up some VDFPeriod objects up to
                 # the number of complete set of VDF_alpha, VDF_beta, and VDF_mu
                 try:
                     VDF_alpha = line[header_vdf_alpha]
@@ -419,7 +420,7 @@ def read_demand(input_dir,
 
     """ step 3:read input_agent """
     with open(input_dir+'/'+file, 'r') as fp:
-        print('read demand.csv')
+        print('read '+file)
 
         at = agent_type_id
         dp = demand_period_id
@@ -432,7 +433,7 @@ def read_demand(input_dir,
             if oz_id is None:
                 continue
 
-            # invalid destinationzone id, discard it
+            # invalid destination zone id, discard it
             dz_id = _convert_str_to_int(line['d_zone_id'])
             if dz_id is None:
                 continue
@@ -472,7 +473,7 @@ def read_demand(input_dir,
 def _auto_setup(assignment):
     """ automatically set up one demand period and one agent type
 
-    The two objects will be set up using the default construnctors using the
+    The two objects will be set up using the default constructors using the
     default values. See class DemandPeriod and class AgentType for details
     """
     at = AgentType()
@@ -524,7 +525,7 @@ def read_settings(input_dir, assignment):
             demands = settings['demand_files']
             for i, d in enumerate(demands):
                 demand_file = d['file_name']
-                # demand_format_tpye = d['format_type']
+                # demand_format_type = d['format_type']
                 demand_period = d['period']
                 demand_type = d['agent_type']
 
@@ -533,7 +534,7 @@ def read_settings(input_dir, assignment):
 
     except ImportError:
         # just in case user does not have pyyaml installed
-        print('Please intall pyyaml next time!')
+        print('Please install pyyaml next time!')
         print('Engine will set up one demand period and one agent type using '
               'default values for you, which might NOT reflect your case!\n')
         _auto_setup(assignment)
@@ -599,7 +600,7 @@ def load_columns(ui, input_dir='.'):
 
         reader = csv.DictReader(f)
 
-        # just in case agent_id was not outputed
+        # just in case agent_id was not output
         last_agent_id = 0
         for line in reader:
             # critical info
@@ -675,9 +676,15 @@ def load_columns(ui, input_dir='.'):
                     f'INVALID NODE PATH found for agent id: {agent_id}'
                 )
 
-            node_sum = sum(node_path)
+            # deprecate node_sum and adopt the same implementation in colgen.py
+            existing = False
+            for col in cv.get_columns().values():
+                if col.get_nodes() == node_path:
+                    col.increase_volume(vol)
+                    existing = True
+                    break
 
-            if node_sum not in cv.path_node_seq_map.keys():
+            if not existing:
                 path_seq_no = cv.get_column_num()
                 col = Column(path_seq_no)
 
@@ -706,6 +713,7 @@ def load_columns(ui, input_dir='.'):
                     )
 
                 # the following four are non-critical info
+                col.set_volume(vol)
                 col.set_toll(toll)
                 col.set_travel_time(tt)
                 col.set_geometry(geo)
@@ -714,9 +722,7 @@ def load_columns(ui, input_dir='.'):
                     sum(A.get_link(x).get_length() for x in col.links)
                 col.set_distance(dist)
 
-                cv.add_new_column(node_sum, col)
-
-            cv.get_column(node_sum).increase_volume(vol)
+                cv.add_new_column(path_seq_no, col)
 
         update_links_using_columns(ui)
 
@@ -882,16 +888,15 @@ def output_agent_paths(ui, output_geometry=True, output_dir='.'):
 
         pre_dest_node_id = -1
         for a in agents:
+            if not a.get_node_path():
+               continue
+
             if a.get_dest_node_id() == pre_dest_node_id:
                 continue
 
             pre_dest_node_id = a.get_dest_node_id()
-
             agent_id = a.get_id()
 
-            if not a.get_node_path():
-               continue
-
             geometry = ''
             if output_geometry:
                 geometry = ', '.join(
